CSS Highlighter — BCI-Framework documentation

# CSS Highlighter

QSyntaxHighlighter for CSS syntax.

class `bci_framework.framework.editor.highlighters.css_syntax.` `CSSHighlighter`(document)

  Syntax highlighter for CSS style sheets.

  classmethod `get_format`(color: str, style='', fontsize=None) → PySide2.QtGui.QTextCharFormat

    Return a QTextCharFormat with the given attributes.

  `highlightBlock`(text: str) → None

    Apply syntax highlighting to the given block of text.

  property `styles`

    The styles depend on the theme.